diff --git a/app/views/commercials/edit.html.haml b/app/views/commercials/edit.html.haml
index 174a1a60..359f27a8 100644
--- a/app/views/commercials/edit.html.haml
+++ b/app/views/commercials/edit.html.haml
@@ -2,7 +2,7 @@
.row
.col-md-12
.page-header
- %h1 Editing Commercial
+ %h1 Edit Materials
.row
.col-md-12
= semantic_form_for @commercial, url: conference_program_proposal_commercial_path(conference_id: @conference.short_title, proposal_id: @event.id, id: @commercial.id) do |f|
diff --git a/app/views/commercials/new.html.haml b/app/views/commercials/new.html.haml
index da726e89..4152ff88 100644
--- a/app/views/commercials/new.html.haml
+++ b/app/views/commercials/new.html.haml
@@ -2,7 +2,7 @@
.row
.col-md-12
.page-header
- %h1 New Commercial
+ %h1 New Materials
.row
.col-md-12
= semantic_form_for @commercial, url: conference_program_proposal_commercials_path(conference_id: @conference.short_title, proposal_id: @event.id) do |f|
diff --git a/spec/features/commercials_spec.rb b/spec/features/commercials_spec.rb
index a0710f86..3dfaea1f 100644
--- a/spec/features/commercials_spec.rb
+++ b/spec/features/commercials_spec.rb
@@ -17,7 +17,7 @@ feature Commercial do
# Create valid commercial
fill_in 'commercial_url', with: 'https://www.youtube.com/watch?v=M9bq_alk-sw'
- click_button 'Create Commercial'
+ click_button 'Save Materials'
page.find('#flash')
expect(flash).to eq('Commercial was successfully created.')
page.find('#flash .button.close').click
@@ -59,10 +59,10 @@ feature Commercial do
click_link 'Commercials'
fill_in 'commercial_url', with: 'https://www.youtube.com/watch?v=M9bq_alk-sw'
# Workaround to enable the 'Create Commercial' button
page.execute_script("$('#commercial_submit_action').prop('disabled', false)")
- click_button 'Create Commercial'
+ click_button 'Save Materials'
page.find('#flash')
expect(flash).to eq('Commercial was successfully created.')
end
@@ -72,7 +72,7 @@ feature Commercial do
click_link 'Commercials'
fill_in 'commercial_url', with: 'invalid_commercial_url'
expect(page).to have_content('No embeddable content')
- expect(page).to have_css("button[type='submit']:disabled", text: 'Create Commercial')
+ expect(page).to have_css("button[type='submit']:disabled", text: 'Save Materials')
end
scenario 'updates a commercial of an event', feature: true, js: true do
@@ -59,10 +59,10 @@ feature Commercial do
click_link 'Commercials'
fill_in 'commercial_url', with: 'https://www.youtube.com/watch?v=M9bq_alk-sw'
- # Workaround to enable the 'Create Commercial' button
+ # Workaround to enable the 'Save Materials' button
page.execute_script("$('#commercial_submit_action').prop('disabled', false)")